summaryrefslogtreecommitdiff
path: root/sw/source/core/layout/dumpfilter.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/layout/dumpfilter.cxx')
-rw-r--r--sw/source/core/layout/dumpfilter.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/sw/source/core/layout/dumpfilter.cxx b/sw/source/core/layout/dumpfilter.cxx
index 9ec20ba597b1..36d28c7d4403 100644
--- a/sw/source/core/layout/dumpfilter.cxx
+++ b/sw/source/core/layout/dumpfilter.cxx
@@ -87,12 +87,12 @@ namespace sw
utl::MediaDescriptor::PROP_OUTPUTSTREAM(),
uno::Reference< io::XOutputStream >() );
// Actually get the SwRootFrm to call dumpAsXml
uno::Reference< lang::XUnoTunnel > xDocTunnel( m_xSrcDoc, uno::UNO_QUERY );
SwXTextDocument* pXDoc = UnoTunnelGetImplementation< SwXTextDocument >( xDocTunnel );
if ( pXDoc )
{
- SwRootFrm* pLayout = pXDoc->GetDocShell()->GetWrtShell()->GetLayout();
+ SwRootFrame* pLayout = pXDoc->GetDocShell()->GetWrtShell()->GetLayout();
// Get sure that the whole layout is processed: set a visible area
// even though there isn't any need of it
@@ -87,12 +87,12 @@ namespace sw
utl::MediaDescriptor::PROP_OUTPUTSTREAM(),
uno::Reference< io::XOutputStream >() );
- // Actually get the SwRootFrm to call dumpAsXml
+ // Actually get the SwRootFrame to call dumpAsXml
uno::Reference< lang::XUnoTunnel > xDocTunnel( m_xSrcDoc, uno::UNO_QUERY );
SwXTextDocument* pXDoc = UnoTunnelGetImplementation< SwXTextDocument >( xDocTunnel );